@@ -74,7 +74,7 @@ protected:
     bool put(events *event);
 
 public:
-    typedef enum {NOTICE, WARNING, FAILURE, TERMINATE, STATE, REALM, CALL, DROP, ACTIVATE, RELEASE, WELCOME, SYNC} type_t;
+    typedef enum {NOTICE, WARNING, FAILURE, TERMINATE, STATE, REALM, CALL, DROP, ACTIVATE, RELEASE, WELCOME, SYNC, CONTACT, PUBLISH} type_t;
 
     /**
      * Type of event message.
@@ -103,6 +103,7 @@ public:
             char state[32];
             char realm[64];
         } server;
+        char contact[160];
         char reason[160];
         unsigned period;
     };
@@ -175,6 +176,17 @@ public:
      */
     static void failure(const char *reason);
 
+    /**
+     * Refresh clients with any config events...
+     */
+    static void reload(void);
+
+    /**
+     * Update publish address...
+     * @param published address.
+     */
+    static void publish(const char *address);
+
     /**
      * Notify server termination.
      * @param reason server terminated.
