@@ -13,7 +13,9 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-#include <config.h>
+#undef  HAVE_CONFIG_H
+
+#include <sipwitch-config.h>
 #include <eXosip2/eXosip.h>
 #include <ucommon/ucommon.h>
 
@@ -28,14 +30,31 @@ static const char *binding = NULL;
 static unsigned timeout = 1000;
 static int tls = 0;
 
+#if defined(EXOSIP_OPT_BASE_OPTION) && !defined(EXOSIP_OPT_DONT_SEND_101)
+#define EXOSIP_API4
+#endif
+
+#ifdef  EXOSIP_API4
+#define EXOSIP_CONTEXT  context
+#define OPTION_CONTEXT  context,
+#define EXOSIP_LOCK     eXosip_lock(context);
+#define EXOSIP_UNLOCK   eXosip_unlock(context);
+static struct eXosip_t *context = NULL;
+#else
+#define EXOSIP_LOCK     eXosip_lock();
+#define EXOSIP_UNLOCK   eXosip_unlock();
+#define EXOSIP_CONTEXT
+#define OPTION_CONTEXT
+#endif
+
+using namespace UCOMMON_NAMESPACE;
+
 #if defined(_MSWINDOWS_) && defined(__GNUC__)
 // binds addrinfo for mingw32 linkage since otherwise mingw32 cannot
 // cannot link proper getaddrinfo/freeaddrinfo calls that eXosip uses.
 static Socket::address localhost("127.0.0.1");
 #endif
 
-using namespace UCOMMON_NAMESPACE;
-
 PROGRAM_MAIN(argc, argv)
 {
     int error = 2;
@@ -197,7 +216,11 @@ usage:
         port = 5060 + getuid();
 #endif
 
-    if(eXosip_init())
+#ifdef  EXOSIP_API4
+    context = eXosip_malloc();
+#endif
+
+    if(eXosip_init(EXOSIP_CONTEXT))
         shell::errexit(3, "*** sipuser: failed exosip init\n");
 
 #ifdef  AF_INET6
@@ -208,7 +231,7 @@ usage:
     }
 #endif
 
-    if(eXosip_listen_addr(protocol, binding, port, family, tls)) {
+    if(eXosip_listen_addr(OPTION_CONTEXT protocol, binding, port, family, tls)) {
 #ifdef  AF_INET6
         if(!binding && family == AF_INET6)
             binding = "::0";
@@ -219,9 +242,9 @@ usage:
     }
 
     if(forwarded)
-        eXosip_masquerade_contact(forwarded, port);
+        eXosip_masquerade_contact(OPTION_CONTEXT forwarded, port);
 
-    eXosip_set_user_agent("SIPW/sipquery");
+    eXosip_set_user_agent(OPTION_CONTEXT "SIPW/sipquery");
 
     if(!strncmp(user, "sip:", 4)) {
         tls = 0;
@@ -270,20 +293,20 @@ usage:
         snprintf(buffer, sizeof(buffer), "sip:%s", user);
 
 
-    eXosip_lock();
-    rid = eXosip_register_build_initial_register(buffer, proxy, NULL, 60, &msg);
+    EXOSIP_LOCK
+    rid = eXosip_register_build_initial_register(OPTION_CONTEXT buffer, proxy, NULL, 60, &msg);
     if(!msg) {
-        eXosip_unlock();
+        EXOSIP_UNLOCK
         shell::errexit(3, "*** sipuser: cannot create query for %s\n", user);
     }
     snprintf(tbuffer, sizeof(tbuffer), "<%s>", buffer);
     osip_message_set_to(msg, tbuffer);
     osip_list_ofchar_free(&msg->contacts);
-    eXosip_register_send_register(rid, msg);
-    eXosip_unlock();
+    eXosip_register_send_register(OPTION_CONTEXT rid, msg);
+    EXOSIP_UNLOCK
 
     while(!stop) {
-        sevent = eXosip_event_wait(0, timeout);
+        sevent = eXosip_event_wait(OPTION_CONTEXT 0, timeout);
         if(!sevent)
             shell::errexit(2, "*** sipuser: timed out\n");
 
@@ -307,8 +330,8 @@ usage:
 
         eXosip_event_free(sevent);
     }
-    eXosip_register_remove(rid);
-    eXosip_quit();
+    eXosip_register_remove(OPTION_CONTEXT rid);
+    eXosip_quit(EXOSIP_CONTEXT);
     PROGRAM_EXIT(error);
 }
 
